@@ -1,11 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Pheanstalk;
 
 /**
  * An exception originating from the Pheanstalk package.
- *
- * @author  Paul Annesley
+ * @extensible
  */
 class Exception extends \Exception
 {
