@@ -1,11 +1,14 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Pheanstalk\Exception;
 
 use Pheanstalk\Exception;
 
 /**
  * An exception originating from the beanstalkd client.
+ * @extensible
  */
 class ClientException extends Exception
 {
